==> haskell-extra-1.6.4-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-extra.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: extra
version: 1.6.4
id: extra-1.6.4-IR1oQDuzGtgJSLCzznTeLE
key: extra-1.6.4-IR1oQDuzGtgJSLCzznTeLE
license: BSD3
copyright: Neil Mitchell 2014-2018
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/extra#readme
synopsis: Extra functions I use.
description:
    A library of extra functions for the standard Haskell libraries. Most functions are simple additions, filling out missing functionality. A few functions are available in later versions of GHC, but this package makes them available back to GHC 7.2.
    .
    The module "Extra" documents all functions provided by this library. Modules such as "Data.List.Extra" provide extra functions over "Data.List" and also reexport "Data.List". Users are recommended to replace "Data.List" imports with "Data.List.Extra" if they need the extra functionality.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.Extra Control.Exception.Extra
    Control.Monad.Extra Data.Either.Extra Data.IORef.Extra
    Data.List.Extra Data.Tuple.Extra Data.Typeable.Extra
    Data.Version.Extra Extra Numeric.Extra System.Directory.Extra
    System.Environment.Extra System.IO.Extra System.Info.Extra
    System.Process.Extra System.Time.Extra Text.Read.Extra
hidden-modules: Partial
abi: 58fe223e93bb16a10e7d42b22a8195bc
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/extra-1.6.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/extra-1.6.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/extra-1.6.4
hs-libraries: HSextra-1.6.4-IR1oQDuzGtgJSLCzznTeLE
depends:
    base-4.10.1.0 directory-1.3.0.2 filepath-1.4.1.2 process-1.6.1.0
    clock-0.7.2-HOYfHHJ3W4Qjx04GjA0Jy time-1.8.0.2 unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             clock-0.7.2-HOYfHHJ3W4Qjx04GjA0Jy=01c820dbfea727c150599d4a04cd30b6
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-extra/html/extra.haddock
haddock-html: /usr/share/doc/haskell-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-extra-1.6.5-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-extra.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: extra
version: 1.6.5
id: extra-1.6.5-IBupi4htDLmBkl2G52nnJu
key: extra-1.6.5-IBupi4htDLmBkl2G52nnJu
license: BSD3
copyright: Neil Mitchell 2014-2018
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/extra#readme
synopsis: Extra functions I use.
description:
    A library of extra functions for the standard Haskell libraries. Most functions are simple additions, filling out missing functionality. A few functions are available in later versions of GHC, but this package makes them available back to GHC 7.2.
    .
    The module "Extra" documents all functions provided by this library. Modules such as "Data.List.Extra" provide extra functions over "Data.List" and also reexport "Data.List". Users are recommended to replace "Data.List" imports with "Data.List.Extra" if they need the extra functionality.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.Extra Control.Exception.Extra
    Control.Monad.Extra Data.Either.Extra Data.IORef.Extra
    Data.List.Extra Data.Tuple.Extra Data.Typeable.Extra
    Data.Version.Extra Extra Numeric.Extra System.Directory.Extra
    System.Environment.Extra System.IO.Extra System.Info.Extra
    System.Process.Extra System.Time.Extra Text.Read.Extra
hidden-modules: Partial
abi: 0784004f366ef8a06fd456c4fd01768b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/extra-1.6.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/extra-1.6.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/extra-1.6.5
hs-libraries: HSextra-1.6.5-IBupi4htDLmBkl2G52nnJu
depends:
    base-4.10.1.0 directory-1.3.0.2 filepath-1.4.1.2 process-1.6.1.0
    clock-0.7.2-HOYfHHJ3W4Qjx04GjA0Jy time-1.8.0.2 unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             clock-0.7.2-HOYfHHJ3W4Qjx04GjA0Jy=01c820dbfea727c150599d4a04cd30b6
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-extra/html/extra.haddock
haddock-html: /usr/share/doc/haskell-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
